package com.ruoyi.project.zjsgfa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.zjsgfa.mapper.SjDcfxTsyxMapper;
import com.ruoyi.project.zjsgfa.domain.SjDcfxTsyx;
import com.ruoyi.project.zjsgfa.service.ISjDcfxTsyxService;

/**
 * 设计-地层分析-特殊岩性提示Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-08-08
 */
@Service
public class SjDcfxTsyxServiceImpl implements ISjDcfxTsyxService 
{
    @Autowired
    private SjDcfxTsyxMapper sjDcfxTsyxMapper;

    /**
     * 查询设计-地层分析-特殊岩性提示
     * 
     * @param id 设计-地层分析-特殊岩性提示主键
     * @return 设计-地层分析-特殊岩性提示
     */
    @Override
    public SjDcfxTsyx selectSjDcfxTsyxById(Long id)
    {
        return sjDcfxTsyxMapper.selectSjDcfxTsyxById(id);
    }

    /**
     * 查询设计-地层分析-特殊岩性提示列表
     * 
     * @param sjDcfxTsyx 设计-地层分析-特殊岩性提示
     * @return 设计-地层分析-特殊岩性提示
     */
    @Override
    public List<SjDcfxTsyx> selectSjDcfxTsyxList(SjDcfxTsyx sjDcfxTsyx)
    {
        return sjDcfxTsyxMapper.selectSjDcfxTsyxList(sjDcfxTsyx);
    }

    /**
     * 新增设计-地层分析-特殊岩性提示
     * 
     * @param sjDcfxTsyx 设计-地层分析-特殊岩性提示
     * @return 结果
     */
    @Override
    public int insertSjDcfxTsyx(SjDcfxTsyx sjDcfxTsyx)
    {
        return sjDcfxTsyxMapper.insertSjDcfxTsyx(sjDcfxTsyx);
    }

    /**
     * 修改设计-地层分析-特殊岩性提示
     * 
     * @param sjDcfxTsyx 设计-地层分析-特殊岩性提示
     * @return 结果
     */
    @Override
    public int updateSjDcfxTsyx(SjDcfxTsyx sjDcfxTsyx)
    {
        return sjDcfxTsyxMapper.updateSjDcfxTsyx(sjDcfxTsyx);
    }

    /**
     * 批量删除设计-地层分析-特殊岩性提示
     * 
     * @param ids 需要删除的设计-地层分析-特殊岩性提示主键
     * @return 结果
     */
    @Override
    public int deleteSjDcfxTsyxByIds(Long[] ids)
    {
        return sjDcfxTsyxMapper.deleteSjDcfxTsyxByIds(ids);
    }

    /**
     * 删除设计-地层分析-特殊岩性提示信息
     * 
     * @param id 设计-地层分析-特殊岩性提示主键
     * @return 结果
     */
    @Override
    public int deleteSjDcfxTsyxById(Long id)
    {
        return sjDcfxTsyxMapper.deleteSjDcfxTsyxById(id);
    }
}
